import {Area} from './Area';
import {Bar} from './Bar';
import {BarLine} from './BarLine';
import {Card} from './Card';
import {ChartTypeNotFound} from './ChartTypeNotFound';
import {ChartViewAbstract} from './ChartViewAbstract';
import {ChartViewInterface} from './ChartViewInterface';
import {Column} from './Column';
import {Donut} from './Donut';
import {DonutPivot} from './DonutPivot';
import {Line} from './Line';
import {Pie} from './Pie';
import {PiePivot} from './PiePivot';
import {Gauge} from './Gauge';
import { PeriodList } from './PeriodList';
import { PeriodListCompare } from './PeriodListCompare';
import { ProgressDetail } from './ProgressDetail';
import { Grid } from './Grid';
import { ListCard } from './ListCard';
import { Crosstab } from './Crosstab';
import { CardDetail } from './CardDetail';

export class ChartViewFactory {

    static TYPE_ID_AREA = "59652c388cde464323c18d7b";
	static TYPE_ID_BAR = "596507668cde464323c18d7a";
	static TYPE_ID_BARLINE = "5898c8f3ca6bc3c1f61960d9";
	static TYPE_ID_COLUMN = "579106a111e8f41bb00caff6";
	static TYPE_ID_CROSSTAB = "570ea585c0cef5c05f6f5dfd";
	static TYPE_ID_CARD = "57b368d4adda8e5b20295f6c";
	static TYPE_ID_CARD_DETAIL = "581b72bde237895b2ec91916";
	static TYPE_ID_DONUT = "5853f6aefd12fc7a7066a18a";
	static TYPE_ID_DONUT_PIVOT = "58762a1bca6bc3c1f61960bf";
	static TYPE_ID_GAUGE = "57ab6a47574698ae9522f97e";
	static TYPE_ID_GRID = "56200912f038efbfa1f75105";
	static TYPE_ID_LINE = "585acc747729e554c8693172";
	static TYPE_ID_LIST_CARD = "58a5e65c3a34b43690ebda1d";
	static TYPE_ID_PERIODS_LIST = "574f230498ba51386fab2a8a";
	static TYPE_ID_PERIODS_LIST_COMPARE = "574f230498ba51386fab2a81";
	static TYPE_ID_PIE_PIVOT = "58762a38ca6bc3c1f61960c0";
	static TYPE_ID_PIE = "579106aa11e8f41bb00caff7";
	static TYPE_ID_PROGRESS_DETAIL = "58a6378a3a34b43690ebda2e";

    public static getChartType(viewTypeId: string, dashboard: any, widget: any) {
        let returnChartType;
        switch (viewTypeId) {
            case this.TYPE_ID_AREA:
                returnChartType = Area.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_BAR:
                returnChartType = Bar.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_BARLINE:
                returnChartType = BarLine.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_COLUMN:
                returnChartType = Column.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_CROSSTAB:
                returnChartType = Crosstab.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_CARD:
                returnChartType = Card.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_CARD_DETAIL:
                returnChartType = CardDetail.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_DONUT:
                returnChartType = Donut.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_DONUT_PIVOT:
                returnChartType = DonutPivot.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_GAUGE:
                returnChartType = Gauge.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_GRID:
                returnChartType = Grid.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_LINE:
                returnChartType = Line.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_LIST_CARD:
                returnChartType = ListCard.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_PERIODS_LIST:
                returnChartType = PeriodList.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_PERIODS_LIST_COMPARE:
                returnChartType = PeriodListCompare.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_PIE_PIVOT:
                returnChartType = PiePivot.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_PIE:
                returnChartType = Pie.getWidget(dashboard, widget);
                break;
            case this.TYPE_ID_PROGRESS_DETAIL:
                returnChartType = ProgressDetail.getWidget(dashboard, widget);
                break;
            default:
                returnChartType = "CharType não encontrado";
                break;
        }
        return returnChartType;
    }
}
